@@ -5,14 +5,14 @@ use Types::Standard qw( Bool );
 use Moo::Role;
 requires qw( ppi_document debug );
 
-our $VERSION = '0.27_05';
+our $VERSION = '0.27_07';
 use English qw( -no_match_vars );
 use version;
 use constant {TRUE => 1, FALSE => 0,};
 use Try::Tiny;
 
 has 'min_ver_fast' =>
-  (is => 'rw', isa => Bool, builder => '_build_min_ver_fast',);
+  (is => 'lazy', isa => Bool,);# builder => '_build_min_ver_fast',);
 
 sub _build_min_ver_fast {
   my $self = shift;
@@ -27,7 +27,7 @@ sub _build_min_ver_fast {
       return TRUE;
     }
   };
-  return;
+
 }
 
 #######
@@ -89,7 +89,7 @@ App::Midgen::Roles::FindMinVersion - used by L<App::Midgen>
 
 =head1 VERSION
 
-version: 0.27_05
+version: 0.27_07
 
 =head1 METHODS
 
