@@ -3,14 +3,15 @@ package App::Midgen::Role::Output;
 use v5.10;
 use Moo::Role;
 with qw(
-	App::Midgen::Role::Output::MIdsl
-	App::Midgen::Role::Output::MI
-	App::Midgen::Role::Output::MB
-	App::Midgen::Role::Output::Dzil
-	App::Midgen::Role::Output::Dist
 	App::Midgen::Role::Output::CPANfile
-	App::Midgen::Role::Output::METAjson
+	App::Midgen::Role::Output::Dist
+	App::Midgen::Role::Output::Dzil
+	App::Midgen::Role::Output::EUMM
 	App::Midgen::Role::Output::Infile
+	App::Midgen::Role::Output::MB
+	App::Midgen::Role::Output::METAjson
+	App::Midgen::Role::Output::MI
+	App::Midgen::Role::Output::MIdsl
 );
 requires qw( format distribution_name get_module_version verbose );
 
@@ -20,7 +21,7 @@ no if $] > 5.017010, warnings => 'experimental::smartmatch';
 # Load time and dependencies negate execution time
 # use namespace::clean -except => 'meta';
 
-our $VERSION = '0.27_05';
+our $VERSION = '0.27_07';
 use English qw( -no_match_vars ); # Avoids reg-ex performance penalty
 local $OUTPUT_AUTOFLUSH = 1;
 
@@ -54,8 +55,8 @@ sub output_header {
 			) if not $self->quiet;
 
 		}
-		when ('dzil') {
-			$self->header_dzil( $self->distribution_name );
+		when ('eumm') {
+			$self->header_eumm( $self->distribution_name );
 		}
 		when ('mb') {
 			$self->header_mb( $self->distribution_name );
@@ -92,8 +93,8 @@ sub output_main_body {
 		when ('cpanfile') {
 			$self->body_cpanfile( $title, $required_ref );
 		}
-		when ('dzil') {
-			$self->body_dzil( $title, $required_ref );
+		when ('eumm') {
+			$self->body_eumm( $title, $required_ref );
 		}
 		when ('mb') {
 			$self->body_mb( $title, $required_ref );
@@ -129,8 +130,8 @@ sub output_footer {
 		when ('cpanfile') {
 			$self->footer_cpanfile( $self->distribution_name );
 		}
-		when ('dzil') {
-			$self->footer_dzil( $self->distribution_name );
+		when ('eumm') {
+			$self->footer_eumm( $self->distribution_name );
 		}
 		when ('mb') {
 			$self->footer_mb( $self->distribution_name );
@@ -182,7 +183,7 @@ App::Midgen::Role::Output - A collection of output orientated methods used by L<
 
 =head1 VERSION
 
-version: 0.27_05
+version: 0.27_07
 
 =head1 DESCRIPTION
 
